@@ -1,3 +1,4 @@
+import shutil
 import subprocess
 from pathlib import Path
 from typing import List
@@ -65,15 +66,16 @@ class SourceConverter:
         :param file_path:
         :return html_file_path:
         """
-        html_file_path = Path(str(file_path).replace('project', 'html').replace(file_path.suffix, ".html"))
+        html_file_path = Path(str(file_path).replace('project', 'html') + '.html')
         print(f"html_file_path parent: {html_file_path.parent}")
         html_file_path.parent.mkdir(parents=True, exist_ok=True)
         if file_path.suffix == '.md':
             # Markdown to html with grip
             subprocess.check_output(['grip', '--export', str(file_path)])
             file_path = Path(str(file_path).replace('.md', '.html'))
-            # Replace file dir from project to html
+            # Move file from project to html directory.
             html_file_path = Path(str(file_path).replace('project', 'html'))
+            shutil.move(str(file_path), str(html_file_path))
         else:
             # Source code to html
             with open(file_path, 'r') as f:
@@ -98,9 +100,19 @@ class SourceConverter:
             target_paths.extend(project_folder_path.glob(f"**/{target}"))
         return target_paths
 
+    @staticmethod
+    def _is_binary_file(file_path: Path) -> bool:
+        """
+        Check file is binary or not.
+        :param file_path:
+        :return: bool
+        """
+        with open(file_path, 'rb') as f:
+            return b'\0' in f.read()
+
     def project_to_html(self, project_folder_path: Path, targets: List[str]) -> List[Path]:
         """
-        Convert project to html.
+        Convert project to html. Please specify target files. If target file is binary file, skip it.
         :param project_folder_path:
         :param targets:
         :return: html file paths
@@ -108,6 +120,8 @@ class SourceConverter:
         target_files = self.select_target_files(project_folder_path, targets)
         html_files = []
         for target_file in target_files:
+            if target_file.is_dir(): continue
+            if self._is_binary_file(target_file): continue
             html_file = self.file_to_html(target_file)
             html_files.append(html_file)
         return html_files
